#!/bin/sh
#
# Filename: parseref.sh
# Author: Rob MacLeod
#
# Run the awk script that parses bibliography entries into BiBTeX
#  So far, just two formats, but more to follow
#
## Last update: Fri Oct  9 21:39:46 2009 by Rob Macleod
##    - Added support for initials
# Last update: Sat Nov 18 00:12:00 2000 by Rob MacLeod
#    - created
# Last update: Wed Nov 22 00:40:27 2000 by Rob MacLeod
#    - added two formats
## Last update: Fri Oct  3 07:06:37 2014 by Rob
##    - made this the new version 
## Last update: Sat Dec 24 07:39:44 2022 by Rob
##    - just touched the file to update the date stamp
######################################################################
USAGE="\n Usage: parseref [-i ABC] [-l] infilename(s)  \n
        -i ABC to set initials in keywords\n
	-l to use last name first, e.g., MacLeod, R.S. (instead of R.S. MacLeod)\n "

if [ -z "$ROBHOME" ]
  then
  ROBHOME="/u/macleod"
  export ROBHOME
fi
ECHO="echo"

AWK=gawk
#PARSEPUBMED=${ROBHOME}/litbase/converting/parsepubmed.awk
#PARSECPX=${ROBHOME}/litbase/converting/parsecpx.awk
if [ -r parsepubmed.awk ]
   then
   PARSEPUBMED=parsepubmed.awk
   PARSECPX=parsecpx.awk
   $ECHO "Using local versions of awk files"
 elif [ -r ${HOME}/Dropbox/tex/bibtex/parseref/parsepubmed.awk ]
   then
   PARSEPUBMED=${HOME}/Dropbox/tex/bibtex/parseref/parsepubmed.awk
   PARSECPX=${HOME}/Dropbox/tex/bibtex/parseref/parsecpx.awk
   $ECHO "Using versions of awk files from ${HOME}/Dropbox/tex/bibtex/parseref"
elif [ -r ${HOME}/bin/parsepubmed.awk ]
   then
   PARSEPUBMED=${HOME}/bin/parsepubmed.awk
   PARSECPX=${HOME}/bin/parsecpx.awk
   $ECHO "Using versions of awk files from ${HOME}/bin"
 else
   $ECHO "\nCould not find a version of the required awk file so have to quit"
   exit
 fi
 
######################################################################
# Check input 
if [ $# -lt 1 ]
  then
  $ECHO $USAGE
  exit 1
fi

# Parse arguments:
#  -p = pubmed
# Set the parse script to PubMed style, always a good default.
# At the moment, this is all we really support but the framework is here
# for adding additional formats to parse. 

PARSEAWK=$PARSEPUBMED
convert=p;

while getopts pi:l optval
  do
#  echo "optval = $optval"
  case $optval in
    p) echo "Doing pubmed conversion"
    PARSEAWK=$PARSEPUBMED
    convert=p;;
    i) echo "Initials set to $OPTARG" 
    initials=$OPTARG;;
    l) echo "Using last name first (MacLeod, R.S.)"
    atype=lastnamefirst;;
    \?) echo $USAGE
    exit 2;;
  esac
done

if [ ! -r $PARSEAWK ]
  then
  $ECHO "Cannot find the required awk file $PARSEAWK"
  exit 2
fi

argument=$1
while [ ! -r $argument ]
  do
#  $ECHO "Checking argument = $argument"
  shift
  argument=$1
done

for filename in $*
  do
  $ECHO "\nProcessing file $filename"
  # Make sure the input file is around
  
  if [ ! -r $filename ]
    then
    $ECHO "\n Cannot find the file $filename!!\n"
    exit 2
  fi

  # Parse the input filename and check the extension.
  basefilename=`echo "$filename" | sed 's/[\.][a-zA-Z0-9][a-zA-Z0-9]*$//'`
  fullfilename=`echo "$filename" |  sed 's#[a-zA-Z0-1\.]*/##g'`
  corefilename=`echo "$fullfilename" | sed 's/[\.][a-zA-Z0-9][a-zA-Z0-9]*$//'`
  extension=`echo "$filename" | sed 's/.*\.//'`

  outfilename=${basefilename}.bib

  # Make sure that the output file does not exist already.
  
  if [ -w ${outfilename} ]
    then
    $ECHO "\n\n The desired output file ${outfilename} already exists"
    $ECHO " To overwrite is .............. o"
    $ECHO " To append to the file ........ a"
    $ECHO " Or else exit here ............ return  ? \c"
    read inchar
    if [ "$inchar" = o ]
      then
      /bin/rm -f ${outfilename}
      qappend=""
    elif [ "$inchar" = a ]
      then
      qappend=true
    else
      exit 1
    fi
  fi

  # Do the parsing
  if [ -n "$qappend" ]
    then
   ${AWK} -v initials=$initials -f ${PARSEAWK} authortype="${atype}" $filename >> $outfilename
  else
    ${AWK} -v initials=$initials -f ${PARSEAWK} authortype="${atype}" $filename > $outfilename
  fi

  $ECHO "\nDone making (or appending to) the file $outfilename"
done
